@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.7
+# Version   : 0.3.8
 
 from operator import contains
 import  numpy                   as      np
@@ -1474,7 +1474,7 @@ class AFM:
             x_pos = x_pos * x_scale/x_cells
             y_pos = y_pos * y_scale/y_cells
 
-            self.contact_point = self.contact_point[0]
+            height = height - height[0]
 
             if plot == 'adhesion':
                 plt_title = 'Adhesion (nN)'
